summaryrefslogtreecommitdiffstats
path: root/chrome/browser/importer/toolbar_importer.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/importer/toolbar_importer.h')
-rw-r--r--chrome/browser/importer/toolbar_importer.h14
1 files changed, 9 insertions, 5 deletions
diff --git a/chrome/browser/importer/toolbar_importer.h b/chrome/browser/importer/toolbar_importer.h
index 6ca3a0c..0527b9e 100644
--- a/chrome/browser/importer/toolbar_importer.h
+++ b/chrome/browser/importer/toolbar_importer.h
@@ -19,19 +19,23 @@
#include "base/string16.h"
#include "chrome/browser/importer/importer.h"
#include "chrome/browser/importer/profile_writer.h"
-#include "content/public/common/url_fetcher_delegate.h"
+#include "net/url_request/url_fetcher_delegate.h"
#include "net/url_request/url_request_context_getter.h"
class ImporterBridge;
class XmlReader;
+namespace net {
+class URLFetcher;
+} // namespace net
+
// Toolbar5Importer is a class which exposes the functionality needed to
// communicate with the Google Toolbar v5 front-end, negotiate the download of
// Toolbar bookmarks, parse them, and install them on the client.
// Toolbar5Importer should not have StartImport called more than once. Futher
// if StartImport is called, then the class must not be destroyed until it has
// either completed or Toolbar5Importer->Cancel() has been called.
-class Toolbar5Importer : public content::URLFetcherDelegate, public Importer {
+class Toolbar5Importer : public net::URLFetcherDelegate, public Importer {
public:
Toolbar5Importer();
@@ -48,7 +52,7 @@ class Toolbar5Importer : public content::URLFetcherDelegate, public Importer {
// to cancel network retrieval.
virtual void Cancel() OVERRIDE;
// content::URLFetcherDelegate method called back from the URLFetcher object.
virtual void OnURLFetchComplete(const net::URLFetcher* source) OVERRIDE;
private:
@@ -155,8 +159,8 @@ class Toolbar5Importer : public content::URLFetcherDelegate, public Importer {
// The fetchers need to be available to cancel the network call on user cancel
// hence they are stored as member variables.
- content::URLFetcher* token_fetcher_;
- content::URLFetcher* data_fetcher_;
+ net::URLFetcher* token_fetcher_;
+ net::URLFetcher* data_fetcher_;
// Used to get correct login data for the toolbar server.
scoped_refptr<net::URLRequestContextGetter> request_context_getter_;
@@ -48,7 +52,7 @@ class Toolbar5Importer : public content::URLFetcherDelegate, public Importer {
// to cancel network retrieval.
virtual void Cancel() OVERRIDE;
- // content::URLFetcherDelegate method called back from the URLFetcher object.
+ // net::URLFetcherDelegate method called back from the URLFetcher object.
virtual void OnURLFetchComplete(const net::URLFetcher* source) OVERRIDE;
private: